#!/usr/bin/python
# Coded by Daniel Fernandez 2016
# http://mechanicalforex.com
# https://asirikuy.com

import pandas as pd
from sklearn.decomposition import FastICA
import matplotlib.pyplot as plt
import seaborn as sns


def plot_result(balance):

    fig, ax = plt.subplots(figsize=(12,8), dpi=100)
    ax.axhline(0.0, linestyle='dashed', color='black', linewidth=1.5)
    ax.set_xlabel('Date')
    ax.set_ylabel('Total change (%)') 

    for i, column in enumerate(balance.columns):  
        ax.plot(balance.index, balance[column], label=balance.columns[i]) 
    ax.legend(loc='lower center', ncol= 3, fancybox=True, shadow=True)
    
    ax.set_axisbelow(True)     
        
    plt.show()

def main():

    symbols = ["EURUSD", "EURJPY", "USDJPY"]
    data_timeseries = pd.DataFrame()
    data_returns = pd.DataFrame()
    
    for symbol in symbols:
        rates = pd.read_csv(symbol+"1987_1440.csv", index_col=0, parse_dates=True, dayfirst=True, header=None, names=['open','high','low','close','vol'])
        data_timeseries[symbol] = (1+rates['close'].pct_change(fill_method='pad').ix[1:]).cumprod()
    
    ica_timeseries = FastICA(n_components=3)
    pure_currencies_from_timeseries = pd.DataFrame(ica_timeseries.fit_transform(data_timeseries)).set_index(data_timeseries.index) 
    print "" 
    print "Mixing matrix from time series"
    print ica_timeseries.mixing_
    print ""
            
    plot_result(data_timeseries)
    plot_result(pure_currencies_from_timeseries)

    

    
##################################
###           MAIN           ####
##################################

if __name__ == "__main__": main()
